function struct2fitshead,hdrstr
;+
;   Name: struct2fitshead
;
;   Purpose: Map FITS Header-Structure structure back-> fits header (strarr)
;
;   Input Parameters:
;      hdrstr - IDL structure to map into fits header (ex: output of mreadfits)
;
;   Output:
;      function returns FITS header derived from structure
;
;   Calling Sequence:
;      header=struct2fitshead(structure)
;
;   Calling Example:
;	mreadfits,f,hdr,data
;	ahdr = struct2fitshead(hdr(0))
;	writefits,"new-"+f(0),f(0),ahdr
;
;   History:
;      Craig DeForrest w/S.L.Freeland - 11-apr-1997
;      2-March-1998 - S.L.Freeland - use 'sxaddpar' instead of 'fxaddpar'
;                     (dont worry about missing 'naxis1, etc)   
;
;   Calls:
;      sxaddpar
;
;   LIMITATIONS: PROTOTYPE (functional) 
;                Only works on a single header at a time -- may not be (easily)
;                vectorized.
;-
tags = tag_names(hdrstr)

for i=0,n_elements(tags)-1 do begin
   value=hdrstr.(i)
   if n_elements(value) gt 1 then begin                   ; comment&history
      nonnulls=where(strtrim(value,2) ne '',nncnt)
      for j=0,nncnt-1 do sxaddpar,ohdr,tags(i),(hdrstr.(i))(nonnulls(j))
   endif else begin
      value=hdrstr.(i)        
      if data_chk(value,/type) eq 1 then value=fix(value)
      sxaddpar,ohdr,tags(i),value
   endelse
endfor

return,ohdr
end


